@@ -70,6 +70,7 @@ from .type import (
     GraphQLIncludeDirective,
     GraphQLSkipDirective,
     GraphQLDeprecatedDirective,
+    GraphQLSpecifiedByDirective,
     # "Enum" of Type Kinds
     TypeKind,
     # Constant Deprecation Reason
@@ -180,6 +181,7 @@ from .language import (
     visit,
     ParallelVisitor,
     Visitor,
+    VisitorAction,
     BREAK,
     SKIP,
     REMOVE,
@@ -437,6 +439,7 @@ __all__ = [
     "GraphQLIncludeDirective",
     "GraphQLSkipDirective",
     "GraphQLDeprecatedDirective",
+    "GraphQLSpecifiedByDirective",
     "TypeKind",
     "DEFAULT_DEPRECATION_REASON",
     "introspection_types",
@@ -530,6 +533,7 @@ __all__ = [
     "ParallelVisitor",
     "TypeInfoVisitor",
     "Visitor",
+    "VisitorAction",
     "BREAK",
     "SKIP",
     "REMOVE",
