@@ -165,14 +165,14 @@ class GraphQLWrappingType(GraphQLType, Generic[GT]):
 
     of_type: GT
 
-    def __init__(self, type_: GT):
+    def __init__(self, type_: GT) -> None:
         if not is_type(type_):
             raise TypeError(
                 f"Can only create a wrapper for a GraphQLType, but got: {type_}."
             )
         self.of_type = type_
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__} {self.of_type!r}>"
 
 
@@ -237,10 +237,10 @@ class GraphQLNamedType(GraphQLType):
         self.ast_node = ast_node
         self.extension_ast_nodes = extension_ast_nodes
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__} {self.name!r}>"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.name
 
     def to_kwargs(self) -> Dict[str, Any]:
@@ -273,7 +273,7 @@ def get_named_type(type_: GraphQLType) -> GraphQLNamedType:
     ...
 
 
-def get_named_type(type_):
+def get_named_type(type_: Optional[GraphQLType]) -> Optional[GraphQLNamedType]:
     """Unwrap possible wrapping type"""
     if type_:
         unwrapped_type = type_
@@ -293,10 +293,9 @@ def resolve_thunk(thunk: Any) -> Any:
     return thunk() if callable(thunk) else thunk
 
 
-# Unfortunately these types cannot be specified any better in Python:
-GraphQLScalarSerializer = Callable
-GraphQLScalarValueParser = Callable
-GraphQLScalarLiteralParser = Callable
+GraphQLScalarSerializer = Callable[[Any], Any]
+GraphQLScalarValueParser = Callable[[Any], Any]
+GraphQLScalarLiteralParser = Callable[[ValueNode, Optional[Dict[str, Any]]], Any]
 
 
 class GraphQLScalarType(GraphQLNamedType):
@@ -319,6 +318,7 @@ class GraphQLScalarType(GraphQLNamedType):
 
     """
 
+    specified_by_url: Optional[str]
     ast_node: Optional[ScalarTypeDefinitionNode]
     extension_ast_nodes: Optional[FrozenList[ScalarTypeExtensionNode]]
 
@@ -329,6 +329,7 @@ class GraphQLScalarType(GraphQLNamedType):
         parse_value: Optional[GraphQLScalarValueParser] = None,
         parse_literal: Optional[GraphQLScalarLiteralParser] = None,
         description: Optional[str] = None,
+        specified_by_url: Optional[str] = None,
         extensions: Optional[Dict[str, Any]] = None,
         ast_node: Optional[ScalarTypeDefinitionNode] = None,
         extension_ast_nodes: Optional[Collection[ScalarTypeExtensionNode]] = None,
@@ -340,6 +341,11 @@ class GraphQLScalarType(GraphQLNamedType):
             ast_node=ast_node,
             extension_ast_nodes=extension_ast_nodes,
         )
+        if specified_by_url is not None and not isinstance(specified_by_url, str):
+            raise TypeError(
+                f"{name} must provide 'specified_by_url' as a string,"
+                f" but got: {inspect(specified_by_url)}."
+            )
         if serialize is not None and not callable(serialize):
             raise TypeError(
                 f"{name} must provide 'serialize' as a function."
@@ -370,11 +376,12 @@ class GraphQLScalarType(GraphQLNamedType):
             self.parse_value = parse_value  # type: ignore
         if parse_literal is not None:
             self.parse_literal = parse_literal  # type: ignore
+        self.specified_by_url = specified_by_url
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__} {self.name!r}>"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.name
 
     @staticmethod
@@ -418,6 +425,7 @@ class GraphQLScalarType(GraphQLNamedType):
             if getattr(self.parse_literal, "__func__", None)
             is GraphQLScalarType.parse_literal
             else self.parse_literal,
+            specified_by_url=self.specified_by_url,
         )
 
 
@@ -502,13 +510,13 @@ class GraphQLField:
         self.extensions = extensions
         self.ast_node = ast_node
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__} {self.type!r}>"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"Field: {self.type}"
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return self is other or (
             isinstance(other, GraphQLField)
             and self.type == other.type
@@ -621,7 +629,7 @@ class GraphQLArgument:
         self.extensions = extensions
         self.ast_node = ast_node
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return self is other or (
             isinstance(other, GraphQLArgument)
             and self.type == other.type
@@ -931,7 +939,7 @@ class GraphQLUnionType(GraphQLNamedType):
 
     def __init__(
         self,
-        name,
+        name: str,
         types: Thunk[Collection[GraphQLObjectType]],
         resolve_type: Optional[GraphQLTypeResolver] = None,
         description: Optional[str] = None,
@@ -1212,7 +1220,7 @@ class GraphQLEnumValue:
         self.extensions = extensions
         self.ast_node = ast_node
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return self is other or (
             isinstance(other, GraphQLEnumValue)
             and self.value == other.value
@@ -1400,7 +1408,7 @@ class GraphQLInputField:
         self.extensions = extensions
         self.ast_node = ast_node
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return self is other or (
             isinstance(other, GraphQLInputField)
             and self.type == other.type
@@ -1447,10 +1455,10 @@ class GraphQLList(Generic[GT], GraphQLWrappingType[GT]):
                 }
     """
 
-    def __init__(self, type_: GT):
+    def __init__(self, type_: GT) -> None:
         super().__init__(type_=type_)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"[{self.of_type}]"
 
 
@@ -1495,7 +1503,7 @@ class GraphQLNonNull(GraphQLWrappingType[GNT], Generic[GNT]):
                 f" {type_}."
             )
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"{self.of_type}!"
 
 
@@ -1557,7 +1565,9 @@ def get_nullable_type(type_: GraphQLNonNull) -> GraphQLNullableType:
     ...
 
 
-def get_nullable_type(type_):
+def get_nullable_type(
+    type_: Optional[Union[GraphQLNullableType, GraphQLNonNull]]
+) -> Optional[GraphQLNullableType]:
     """Unwrap possible non-null type"""
     if is_non_null_type(type_):
         type_ = cast(GraphQLNonNull, type_)
