@@ -317,9 +317,7 @@ class GraphQLSchema:
         return self.is_sub_type(abstract_type, possible_type)
 
     def is_sub_type(
-        self,
-        abstract_type: GraphQLAbstractType,
-        maybe_sub_type: Union[GraphQLObjectType, GraphQLInterfaceType],
+        self, abstract_type: GraphQLAbstractType, maybe_sub_type: GraphQLNamedType,
     ) -> bool:
         """Check whether a type is a subtype of a given abstract type."""
         types = self._sub_type_map.get(abstract_type.name)
@@ -347,7 +345,7 @@ class GraphQLSchema:
         return None
 
     @property
-    def validation_errors(self):
+    def validation_errors(self) -> Optional[List[GraphQLError]]:
         return self._validation_errors
 
 
