@@ -1,3 +1,5 @@
+from typing import Any
+
 from ...error import GraphQLError
 from ...language import OperationDefinitionNode, OperationType
 from . import ASTValidationRule
@@ -11,7 +13,9 @@ class SingleFieldSubscriptionsRule(ASTValidationRule):
     A GraphQL subscription is valid only if it contains a single root.
     """
 
-    def enter_operation_definition(self, node: OperationDefinitionNode, *_args):
+    def enter_operation_definition(
+        self, node: OperationDefinitionNode, *_args: Any
+    ) -> None:
         if node.operation == OperationType.SUBSCRIPTION:
             if len(node.selection_set.selections) != 1:
                 self.report_error(
