@@ -1,7 +1,7 @@
-from typing import Dict
+from typing import Any, Dict
 
 from ...error import GraphQLError
-from ...language import NameNode, ArgumentNode
+from ...language import ArgumentNode, NameNode, VisitorAction, SKIP
 from . import ASTValidationContext, ASTValidationRule
 
 __all__ = ["UniqueArgumentNamesRule"]
@@ -18,13 +18,13 @@ class UniqueArgumentNamesRule(ASTValidationRule):
         super().__init__(context)
         self.known_arg_names: Dict[str, NameNode] = {}
 
-    def enter_field(self, *_args):
+    def enter_field(self, *_args: Any) -> None:
         self.known_arg_names.clear()
 
-    def enter_directive(self, *_args):
+    def enter_directive(self, *_args: Any) -> None:
         self.known_arg_names.clear()
 
-    def enter_argument(self, node: ArgumentNode, *_args):
+    def enter_argument(self, node: ArgumentNode, *_args: Any) -> VisitorAction:
         known_arg_names = self.known_arg_names
         arg_name = node.name.value
         if arg_name in known_arg_names:
@@ -36,4 +36,4 @@ class UniqueArgumentNamesRule(ASTValidationRule):
             )
         else:
             known_arg_names[arg_name] = node.name
-        return self.SKIP
+        return SKIP
