@@ -1,3 +1,5 @@
+from typing import Any
+
 from ...error import GraphQLError
 from ...language import VariableDefinitionNode, print_ast
 from ...type import is_input_type
@@ -14,7 +16,9 @@ class VariablesAreInputTypesRule(ValidationRule):
     (scalar, enum, or input object).
     """
 
-    def enter_variable_definition(self, node: VariableDefinitionNode, *_args):
+    def enter_variable_definition(
+        self, node: VariableDefinitionNode, *_args: Any
+    ) -> None:
         type_ = type_from_ast(self.context.schema, node.type)
 
         # If the variable type is not an input type, return an error.
